<?php $TRANSLATIONS = array(
"Error (de)activating addressbook." => "Σφάλμα (απ)ενεργοποίησης βιβλίου διευθύνσεων",
"id is not set." => "δεν ορίστηκε id",
"Cannot update addressbook with an empty name." => "Δε μπορεί να γίνει αλλαγή βιβλίου διευθύνσεων χωρίς όνομα",
"No category name given." => "Δεν δόθηκε όνομα κατηγορίας.",
"Error adding group." => "Σφάλμα κατά την προσθήκη ομάδας.",
"Group ID missing from request." => "Το ID ομάδας λείπει από το αίτημα.",
"Contact ID missing from request." => "Το ID επαφής λείπει από το αίτημα.",
"No ID provided" => "Δε δόθηκε ID",
"Error setting checksum." => "Λάθος κατά τον ορισμό checksum ",
"No categories selected for deletion." => "Δε επελέγησαν κατηγορίες για διαγραφή",
"No address books found." => "Δε βρέθηκε βιβλίο διευθύνσεων",
"No contacts found." => "Δεν βρέθηκαν επαφές",
"element name is not set." => "δεν ορίστηκε όνομα στοιχείου",
"checksum is not set." => "δε ορίστηκε checksum ",
"Information about vCard is incorrect. Please reload the page." => "Οι πληροφορίες σχετικά με vCard είναι εσφαλμένες. Παρακαλώ επαναφορτώστε τη σελίδα.",
"Couldn't find vCard for %d." => "Δεν βρέθηκε vCard για %d.",
"Information about vCard is incorrect. Please reload the page: " => "Οι πληροφορίες για τη vCard είναι λανθασμένες.Παρακαλώ ξαναφορτώστε τη σελίδα: ",
"Something went FUBAR. " => "Κάτι χάθηκε στο άγνωστο. ",
"Cannot save property of type \"%s\" as array" => "Αδυναμία αποθήκευσης  ιδιότητας του τύπου \"%s\" ως σειρά",
"Missing IM parameter." => "Λείπει IM παράμετρος.",
"Unknown IM: " => "Άγνωστο IM:",
"No contact ID was submitted." => "Δε υπεβλήθει ID επαφής",
"Error reading contact photo." => "Σφάλμα ανάγνωσης εικόνας επαφής",
"Error saving temporary file." => "Σφάλμα αποθήκευσης προσωρινού αρχείου",
"The loading photo is not valid." => "Η φορτωμένη φωτογραφία δεν είναι έγκυρη",
"Contact ID is missing." => "Λείπει ID επαφής",
"No photo path was submitted." => "Δε δόθηκε διαδρομή εικόνας",
"File doesn't exist:" => "Το αρχείο δεν υπάρχει:",
"Error loading image." => "Σφάλμα φόρτωσης εικόνας",
"Error getting contact object." => "Σφάλμα κατά τη λήψη αντικειμένου επαφής",
"Error getting PHOTO property." => "Σφάλμα κατά τη λήψη ιδιοτήτων ΦΩΤΟΓΡΑΦΙΑΣ.",
"Error saving contact." => "Σφάλμα κατά την αποθήκευση επαφής.",
"Error resizing image" => "Σφάλμα κατά την αλλαγή μεγέθους εικόνας",
"Error cropping image" => "Σφάλμα κατά την περικοπή εικόνας",
"Error creating temporary image" => "Σφάλμα κατά την δημιουργία προσωρινής εικόνας",
"Error finding image: " => "Σφάλμα κατά την εύρεση της εικόνας: ",
"Key is not set for: " => "Δεν έχει ορισθεί πλήκτρο για το:",
"Value is not set for: " => "Δεν έχει ορισθεί τιμή για το:",
"Could not set preference: " => "Αδυναμία ορισμού προτίμησης:",
"Error uploading contacts to storage." => "Σφάλμα κατά την αποθήκευση επαφών",
"There is no error, the file uploaded with success" => "Δεν υπάρχει σφάλμα, το αρχείο ανέβηκε με επιτυχία ",
"The uploaded file exceeds the upload_max_filesize directive in php.ini" => "Το μέγεθος του αρχείου ξεπερνάει το upload_max_filesize του php.ini",
"The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" => "Το ανεβασμένο αρχείο υπερβαίνει το MAX_FILE_SIZE που ορίζεται στην  HTML φόρμα",
"The uploaded file was only partially uploaded" => "Το αρχείο ανέβηκε μερικώς",
"No file was uploaded" => "Δεν ανέβηκε κάποιο αρχείο",
"Missing a temporary folder" => "Λείπει ο προσωρινός φάκελος",
"Couldn't save temporary image: " => "Δεν ήταν δυνατή η αποθήκευση της προσωρινής εικόνας: ",
"Couldn't load temporary image: " => "Δεν ήταν δυνατή η φόρτωση της προσωρινής εικόνας: ",
"No file was uploaded. Unknown error" => "Δεν ανέβηκε κάποιο αρχείο. Άγνωστο σφάλμα",
"Contacts" => "Επαφές",
"%d_selected_contacts" => "%d_επιλεγμένες_επαφές",
"Add to..." => "Προσθήκη στο...",
"Remove from..." => "Αφαίρεση από το...",
"Add group..." => "Προσθήκη ομάδας...",
"Indexing contacts" => "Εύρεση επαφών ",
"Select photo" => "Επέλεξε φωτογραφία",
"Network or server error. Please inform administrator." => "Σφάλμα δικτύου ή διακομιστή. Παρακαλώ ενημερώστε το διαχειριστή.",
"Error adding to group." => "Σφάλμα κατά την προσθήκη σε ομάδα.",
"Error removing from group." => "Σφάλμα κατά την αφαίρεση από ομάδα.",
"There was an error opening a mail composer." => "Υπήρχε ένα σφάλμα στο άνοιγμα μίας σύνθεσης μηνύματος.",
"Deleting done. Click here to cancel reloading." => "Η διαγραφή ολοκληρώθηκε. Κλικ εδώ για να ακυρώσετε την επαναφόρτωση.",
"Add address book" => "Προσθήκη βιβλίου διευθύνσεων",
"Import done. Click here to cancel reloading." => "Η εισαγωγή ολοκληρώθηκε. Κλικ εδώ για να ακυρώσετε την επαναφόρτωση.",
"Not all files uploaded. Retrying..." => "Δεν μεταφορτώθηκαν όλα τα αρχεία. Προσπάθεια ξανά...",
"Something went wrong with the upload, please retry." => "Κάτι πήγε στραβά με την μεταφόρτωση, παρακαλώ προσπαθήστε ξανά.",
"Error" => "Σφάλμα",
"Importing from {filename}..." => "Εισαγωγή από {filename}...",
"{success} imported, {failed} failed." => "{success} έγινε εισαγωγή, {failed} απέτυχε.",
"Importing..." => "Γίνεται εισαγωγή...",
"Unable to upload your file as it is a directory or has 0 bytes" => "Αδυναμία στην αποστολή του αρχείου σας αφού είναι φάκελος ή έχει 0 bytes",
"Upload Error" => "Σφάλμα Αποστολής",
"The file you are trying to upload exceed the maximum size for file uploads on this server." => "Το αρχείο που προσπαθείτε να ανεβάσετε υπερβαίνει το μέγιστο μέγεθος για τις προσθήκες αρχείων σε αυτόν τον server.",
"Upload too large" => "Πολύ μεγάλο αρχείο προς αποστολή",
"Pending" => "Εκκρεμεί",
"Add group" => "Προσθήκη ομάδας",
"No files selected for upload." => "Δεν επιλέχτηκαν αρχεία για μεταφόρτωση",
"Edit profile picture" => "Επεξεργασία εικόνας προφίλ",
"Error loading profile picture." => "Σφάλμα στην φόρτωση εικόνας προφίλ.",
"Enter name" => "Εισαγωγή ονόματος",
"Enter description" => "Εισαγωγή περιγραφής",
"Select addressbook" => "Επιλογή βιβλίου επαφών",
"The address book name cannot be empty." => "Το όνομα του βιβλίου διευθύνσεων δεν πρέπει να είναι κενό.",
"Is this correct?" => "Είναι σωστό;",
"There was an unknown error when trying to delete this contact" => "Παρουσιάστηκε άγνωστο σφάλμα κατά τη διαγραφή αυτής της επαφής",
"# groups" => "# ομάδες",
"Some contacts are marked for deletion, but not deleted yet. Please wait for them to be deleted." => "Κάποιες επαφές σημειώθηκαν προς διαγραφή,δεν έχουν διαγραφεί ακόμα. Παρακαλώ περιμένετε μέχρι να διαγραφούν.",
"Click to undo deletion of {num} contacts" => "Κλικ για να αναιρέσετε τη διαγραφή {num} επαφών",
"Cancelled deletion of {num}" => "Αναιρέθηκε η διαγραφή {num}",
"Contact is already in this group." => "Η επαφή είναι ήδη σε αυτήν την ομάδα.",
"Contacts are already in this group." => "Οι επαφές είναι ήδη σε αυτήν την ομάδα.",
"Couldn't get contact list." => "Αδυναμία λήψης λίστας επαφών.",
"Contact is not in this group." => "Η επαφή δεν είναι σε αυτή την ομάδα",
"Contacts are not in this group." => "Οι επαφές δεν είναι σε αυτή την ομάδα.",
"A group named {group} already exists" => "Υπάρχει ήδη μια ομάδα με όνομα {group}",
"You can drag groups to\narrange them as you like." => "Μπορείτε να σύρετε τις ομάδες για να⏎τις τακτοποιήσετε όπως θέλετε.",
"All" => "Όλες",
"Favorites" => "Αγαπημένες",
"Shared by {owner}" => "Διαμοιράστηκε από τον {owner}",
"Result: " => "Αποτέλεσμα: ",
" imported, " => " εισάγεται,",
" failed." => " απέτυχε.",
"Displayname cannot be empty." => "Το όνομα προβολής δεν μπορεί να είναι κενό. ",
"Show CardDav link" => "Εμφάνιση συνδέσμου CardDav",
"Show read-only VCF link" => "Εμφάνιση συνδέσμου VCF μόνο για ανάγνωση",
"Download" => "Λήψη",
"Edit" => "Επεξεργασία",
"Delete" => "Διαγραφή",
"Cancel" => "Ακύρωση",
"More..." => "Περισσότερα...",
"Less..." => "Λιγότερα",
"You do not have the permissions to read this addressbook." => "Δεν έχετε δικαιώματα ανάγνωσης αυτού του βιβλίου διευθύνσεων.",
"You do not have the permissions to update this addressbook." => "Δεν έχετε δικαιώματα ενημέρωσης αυτού του βιβλίου διευθύνσεων.",
"There was an error updating the addressbook." => "Υπήρξε σφάλμα κατά την ενημέρωση του βιβλίου διευθύνσεων.",
"You do not have the permissions to delete this addressbook." => "Δεν έχετε δικαιώματα να διαγράψετε αυτό το βιβλίο διευθύνσεων.",
"There was an error deleting this addressbook." => "Υπήρξε σφάλμα κατά την διαγραφή αυτού του βιβλίου διευθύνσεων",
"Jabber" => "Jabber",
"AIM" => "AIM",
"MSN" => "MSN",
"Twitter" => "Twitter",
"GoogleTalk" => "GoogleTalk",
"Facebook" => "Facebook",
"XMPP" => "XMPP",
"ICQ" => "ICQ",
"Yahoo" => "Yahoo",
"Skype" => "Skype",
"QQ" => "QQ",
"GaduGadu" => "GaduGadu",
"Work" => "Εργασία",
"Home" => "Σπίτι",
"Other" => "Άλλο",
"Mobile" => "Κινητό",
"Text" => "Κείμενο",
"Voice" => "Ομιλία",
"Message" => "Μήνυμα",
"Fax" => "Φαξ",
"Video" => "Βίντεο",
"Pager" => "Βομβητής",
"Internet" => "Διαδίκτυο",
"Friends" => "Φίλοι",
"Family" => "Οικογένεια",
"There was an error deleting properties for this contact." => "Παρουσιάστηκε σφάλμα κατά τη διαγραφή των ιδιοτήτων αυτής της επαφής.",
"{name}'s Birthday" => "Τα Γεννέθλια του/της {name}",
"Contact" => "Επαφή",
"You do not have the permissions to add contacts to this addressbook." => "Δεν έχετε δικαιώματα να προσθέσετε επαφές σε αυτό το βιβλίο διευθύνσεων.",
"Could not find the vCard with ID." => "Αδυναμία εύρεσης της vCard με το ID.",
"You do not have the permissions to edit this contact." => "Δεν διαθέτε επαρκή δικαιώματα για την επεξεργασία αυτής της επαφής.",
"Could not find the vCard with ID: " => "Αδυναμία εύρεσης της vCard με το ID:",
"Could not find the Addressbook with ID: " => "Αδυναμία εύρεσης της Βιβλίου Διευθύνσεων με το ID:",
"You do not have the permissions to delete this contact." => "Δεν διαθέτε επαρκή δικαιώματα για την διαγραφή αυτής της επαφής.",
"There was an error deleting this contact." => "Υπήρξε σφάλμα κατά την διαγραφή αυτής της επαφής.",
"Contact not found." => "Δεν βρέθηκε επαφή.",
"HomePage" => "Αρχική Σελίδα",
"New Group" => "Νέα Ομάδα",
"Settings" => "Ρυθμίσεις",
"Address books" => "Βιβλία διευθύνσεων",
"Import" => "Εισαγωγή",
"Select files to import" => "Επιλογή αρχείων για εισαγωγή",
"Select files" => "Επιλογή αρχείων",
"Import into:" => "Εισαγωγή από:",
"OK" => "ΟΚ",
"(De-)select all" => "(Απο-)επιλογή όλων",
"New Contact" => "Νέα επαφή",
"Download Contact(s)" => "Λήψη Επαφής(-ών)",
"Groups" => "Ομάδες",
"Favorite" => "Αγαπημένο",
"Delete Contact" => "Διαγραφή επαφής",
"Close" => "Κλείσιμο  ",
"Keyboard shortcuts" => "Συντομεύσεις πλητρολογίου",
"Navigation" => "Πλοήγηση",
"Next contact in list" => "Επόμενη επαφή στη λίστα",
"Previous contact in list" => "Προηγούμενη επαφή στη λίστα",
"Expand/collapse current addressbook" => "Ανάπτυξη/σύμπτυξη τρέχοντος βιβλίου διευθύνσεων",
"Next addressbook" => "Επόμενο βιβλίο διευθύνσεων",
"Previous addressbook" => "Προηγούμενο βιβλίο διευθύνσεων",
"Actions" => "Ενέργειες",
"Refresh contacts list" => "Ανανέωσε τη λίστα επαφών",
"Add new contact" => "Προσθήκη νέας επαφής",
"Add new addressbook" => "Προσθήκη νέου βιβλίου επαφών",
"Delete current contact" => "Διαγραφή τρέχουσας επαφής",
"<h3>You have no contacts in your addressbook.</h3><p>Add a new contact or import existing contacts from a VCF file.</p>" => "<h3>Δεν έχετε επαφές στο βιβλίο διευθύνσεων.</h3><p>Προσθέστε μία νέα επαφή ή εισάγετε τις υπάρχουσες επαφές σας από ένα αρχείο VCF.</p>",
"Add contact" => "Προσθήκη επαφής",
"Compose mail" => "Σύνθεση μηνύματος",
"Delete group" => "Διαγραφή ομάδας",
"Delete current photo" => "Διαγραφή τρέχουσας φωτογραφίας",
"Edit current photo" => "Επεξεργασία τρέχουσας φωτογραφίας",
"Upload new photo" => "Ανέβασε νέα φωτογραφία",
"Select photo from ownCloud" => "Επέλεξε φωτογραφία από το ownCloud",
"First name" => "Όνομα",
"Additional names" => "Επιπλέον ονόματα",
"Last name" => "Επώνυμο",
"Select groups" => "Επιλέξτε ομάδες",
"Nickname" => "Παρατσούκλι",
"Enter nickname" => "Εισάγετε παρατσούκλι",
"Title" => "Τίτλος",
"Enter title" => "Εισάγετε τίτλο",
"Organization" => "Οργανισμός",
"Enter organization" => "Εισάγετε οργάνωση",
"Birthday" => "Γενέθλια",
"Notes go here..." => "Σημειώσεις...",
"Export as VCF" => "Εξαγωγή ως VCF",
"Add" => "Προσθήκη",
"Phone" => "Τηλέφωνο",
"Email" => "Email",
"Instant Messaging" => "Άμεσα μυνήματα",
"Address" => "Διεύθυνση",
"Note" => "Σημείωση",
"Web site" => "Ιστότοπος",
"Delete contact" => "Διαγραφή επαφής",
"Preferred" => "Προτιμώμενο",
"Please specify a valid email address." => "Παρακαλώ εισήγαγε μια έγκυρη διεύθυνση ηλεκτρονικού ταχυδρομείου",
"someone@example.com" => "someone@example.com",
"Mail to address" => "Αποστολή σε διεύθυνση",
"Delete email address" => "Διαγραφή διεύθυνση email",
"Enter phone number" => "Εισήγαγε αριθμό τηλεφώνου",
"Delete phone number" => "Διέγραψε αριθμό τηλεφώνου",
"Go to web site" => "Πήγαινε στον ιστότοπο",
"Delete URL" => "Διαγραφή URL",
"View on map" => "Προβολή στο χάρτη",
"Delete address" => "Διαγραφή διεύθυνσης",
"1 Main Street" => "Κεντρική Οδός  αρ.1",
"Street address" => "Διεύθυνση οδού",
"12345" => "12345",
"Postal code" => "Ταχυδρομικός Κωδικός",
"Your city" => "Η πόλη σας",
"City" => "Πόλη",
"Some region" => "Κάποια περιοχή",
"State or province" => "Πολιτεία ή επαρχία",
"Your country" => "Η χώρα σας",
"Country" => "Χώρα",
"Instant Messenger" => "Instant Messenger",
"Delete IM" => "Διαγραφή IM",
"Share" => "Μοιράσου",
"Export" => "Εξαγωγή",
"CardDAV link" => "Σύνδεσμος CardDAV",
"The temporary image has been removed from cache." => "Η προσωρινή εικόνα αφαιρέθηκε από την κρυφή μνήμη.",
"CardDAV syncing addresses" => "συγχρονισμός διευθύνσεων μέσω CardDAV ",
"more info" => "περισσότερες πληροφορίες",
"Primary address (Kontact et al)" => "Κύρια διεύθυνση",
"iOS/OS X" => "iOS/OS X",
"Addressbooks" => "Βιβλία διευθύνσεων",
"New Address Book" => "Νέο βιβλίο διευθύνσεων",
"Name" => "Όνομα",
"Description" => "Περιγραφή",
"Save" => "Αποθήκευση"
);
